@@ -30,12 +30,13 @@ class BillingException(Exception):
     pass
 
 class Client(object):
-    def __init__(self, apikey):
+    def __init__(self, apikey, apiserver = API_SERVER):
         self.apikey = apikey
+        self.apiserver = apiserver
 
     def call(self, function, **kw):
         try:
-            data = json.loads(http_post('%s/api/%s/' % (API_SERVER, function), dict(apikey = self.apikey, json = json.dumps(kw, default = api_serialize))))
+            data = json.loads(http_post('%s/api/%s/' % (self.apiserver, function), dict(apikey = self.apikey, json = json.dumps(kw, default = api_serialize))))
         except urllib2.HTTPError, e:
             log.exception(e.fp.read())
             raise e
